@@ -27,8 +27,8 @@
 	function remove_magic_quotes($data) {
 		if (is_array($data) == false) {
 			$data = stripslashes($data);
-		} else foreach ($data as &$value) {
-			$value = remove_magic_quotes($value);
+		} else foreach ($data as $i => $value) {
+			$data[$i] = remove_magic_quotes($value);
 		}
 
 		return $data;
@@ -47,8 +47,8 @@
 							 "[".chr(11).chr(12)."]|".
 							 "[".chr(14)."-".chr(31)."]/";
 			$data = preg_replace($special_chars, "", $data);
-		} else foreach ($data as &$value) {
-			$value = secure_input($value);
+		} else foreach ($data as $i => $value) {
+			$data[$i] = secure_input($value);
 		}
 
 		return $data;
