@@ -26,7 +26,7 @@
 		 */
 		public function __construct() {
 			$arguments = func_get_args();
-			call_user_func_array(array(parent, "__construct"), $arguments);
+			call_user_func_array(array("parent", "__construct"), $arguments);
 
 			/* Table order
 			 */
