@@ -1,6 +1,6 @@
 <?php
 	class security_statistics_model extends graph_model {
-		protected $columns = array("bans", "exploit_attempts");
+		protected $columns = array("bans", "exploit_attempts", "failed_logins");
 		protected $table = "host_statistics";
 	}
 ?>
